Index: src/gpu/GrContextFactory.h |
diff --git a/src/gpu/GrContextFactory.h b/src/gpu/GrContextFactory.h |
index 7fd4b77ce0bb2f7e4c6f31c8a4bce5ace05cc540..b557f98fea08ff036e30ca0aa2ee56623acd6cdb 100644 |
--- a/src/gpu/GrContextFactory.h |
+++ b/src/gpu/GrContextFactory.h |
@@ -116,7 +116,7 @@ public: |
// Returns the GLContext of the given type. If it has not been created yet, |
// NULL is returned instead. |
SkGLContext* getGLContext(GLContextType type) { |
for (int i = 0; i < fContexts.count(); ++i) { |
if (fContexts[i].fType == type) { |
@@ -124,7 +124,7 @@ public: |
} |
} |
- return NULL; |
+ return nullptr; |
} |
const GrContextOptions& getGlobalOptions() const { return fGlobalOptions; } |
@@ -116,7 +116,7 @@ public: |
// Returns the GLContext of the given type. If it has not been created yet, |
- // NULL is returned instead. |
+ // nullptr is returned instead. |
SkGLContext* getGLContext(GLContextType type) { |
for (int i = 0; i < fContexts.count(); ++i) { |